searchNodes=[{"doc":"Documentation for the main Gitea functions. This package is an Elixir interface to our Gitea Server. It contains all functions we need to create repositories, clone, add data to files, commit, push and diff. Some of these functions use Git and others use the REST API . We would obviously prefer if everything was one or the other, but sadly, some things cannot be done via Git or REST so we have adopted a &quot;hybrid&quot; approach. If anything is unclear, please open an issue: github.com/dwyl/ gitea/issues","ref":"Gitea.html","title":"Gitea","type":"module"},{"doc":"clone/1 clones a remote git repository based on git_repo_url returns the path of the local copy of the repository.","ref":"Gitea.html#clone/1","title":"Gitea.clone/1","type":"function"},{"doc":"commit/3 commits the latest changes on the local branch. Accepts the repo_name and a Map of params : params.message : the commit message you want in the log params.full_name : the name of the person making the commit params.email : email address of the person committing.","ref":"Gitea.html#commit/3","title":"Gitea.commit/3","type":"function"},{"doc":"inject_git/0 injects a Git TestDouble in Tests &amp; CI so we don't have duplicate mocks in the downstream app.","ref":"Gitea.html#inject_git/0","title":"Gitea.inject_git/0","type":"function"},{"doc":"local_branch_create/3 creates a branch with the specified name or defaults to &quot;draft&quot;.","ref":"Gitea.html#local_branch_create/3","title":"Gitea.local_branch_create/3","type":"function"},{"doc":"local_file_read/3 reads the raw text from the file_name , params: org_name , repo_name &amp; file_name","ref":"Gitea.html#local_file_read/3","title":"Gitea.local_file_read/3","type":"function"},{"doc":"local_file_write_text/3 writes the desired text , to the file_name in the repo_name . Touches the file in case it doesn't already exist.","ref":"Gitea.html#local_file_write_text/4","title":"Gitea.local_file_write_text/4","type":"function"},{"doc":"push/2 pushes the org_name/repo_name (current active branch) to the remote repository URL. Mocked during test/CI.","ref":"Gitea.html#push/2","title":"Gitea.push/2","type":"function"},{"doc":"Create an organisation on Gitea. The second argument opts is a keyword list value and define the description, full_name and visibility","ref":"Gitea.html#remote_org_create/1","title":"Gitea.remote_org_create/1","type":"function"},{"doc":"Delete an organisation on Gitea.","ref":"Gitea.html#remote_org_delete/1","title":"Gitea.remote_org_delete/1","type":"function"},{"doc":"remote_read_file/4 reads a file from the remote repo. Accepts 4 arguments: org_name , repo_name , file_name and branch_name . The 4&lt;sup&gt;th&lt;/sup&gt; argument is optional and defaults to &quot;master&quot; (the default branch for a repo hosted on Gitea ). Makes a GET request to the remote Gitea instance as defined by the environment variable GITEA_URL . Returns {:ok, %HTTPoison.Response{ body: response_body}} Uses REST API Endpoint: GET /repos/:username/:reponame/raw/:branchname/:path Ref: https://github.com/gitea/docs-api/blob/master/Repositories/Contents.md#get-contents","ref":"Gitea.html#remote_read_raw/4","title":"Gitea.remote_read_raw/4","type":"function"},{"doc":"remote_render_markdown_html/4 uses Gitea built-in Markdown processor to render a Markdown Doc e.g. the README.md so you can easily use the HTML. Accepts 4 arguments: org_name , repo_name , file_name and branch_name . The 4&lt;sup&gt;th&lt;/sup&gt; argument is optional and defaults to &quot;master&quot; (the default branch for a repo hosted on Gitea ). Makes a GET request to the remote Gitea instance as defined by the environment variable GITEA_URL . Returns {:ok, %HTTPoison.Response{ body: response_body}} Uses REST API Endpoint: POST /markdown/raw Ref: https://github.com/dwyl/gitea/issues/23","ref":"Gitea.html#remote_render_markdown_html/4","title":"Gitea.remote_render_markdown_html/4","type":"function"},{"doc":"remote_repo_create/3 accepts 3 arguments: org_name , repo_name &amp; private . It creates a repo on the remote Gitea instance as defined by the environment variable GITEA_URL . For convenience it assumes that you only have one Gitea instance. If you have more or different requirements, please share!","ref":"Gitea.html#remote_repo_create/3","title":"Gitea.remote_repo_create/3","type":"function"},{"doc":"remote_repo_delete/2 accepts two arguments: org_name and repo_name . It deletes the repo on the remote Gitea instance as defined by the environment variable GITEA_URL .","ref":"Gitea.html#remote_repo_delete/2","title":"Gitea.remote_repo_delete/2","type":"function"},{"doc":"Mock functions to simulate Git commands. Sadly, this is necessary until we figure out how to get write-access on GitHub CI. This module is exported for testing convenience/speed in downstream/dependent apps.","ref":"Gitea.GitMock.html","title":"Gitea.GitMock","type":"module"},{"doc":"clone/1 (mock) returns the path of the existing test-repo so that no remote cloning occurs. This is needed for CI and is used in downstream tests to speed up suite execution. ## Examples iex&gt; GitMock.clone(&quot;ssh://gitea-server.fly.dev:10022/myorg/public-repo.git&quot;) {:ok, %Git.Repository{path: &quot;/path/to/public-repo&quot;}} iex&gt; GitMock.clone(&quot;any-url-containing-the-word-error-to-trigger-failure&quot;) {:error, %Git.Error{message: &quot;git clone error (mock)&quot;}}","ref":"Gitea.GitMock.html#clone/1","title":"Gitea.GitMock.clone/1","type":"function"},{"doc":"push/1 (mock) pushes the latest commits on the current branch to the Gitea remote repository. ## Examples iex&gt; GitMock.push(&quot;my-repo&quot;) {:ok, &quot;To ssh://gitea-server.fly.dev:10022/myorg/my-repo.git &quot;}","ref":"Gitea.GitMock.html#push/2","title":"Gitea.GitMock.push/2","type":"function"},{"doc":"Mock (stub) our API requests to the Gitea API so that we can test all of our code (with Mocks) on GitHub CI. These functions pattern match on the params and return the expected responses. If you know of a better way of doing this (preferably without introducing more dependencies ...) Please share: github.com/dwyl/ gitea/issues","ref":"Gitea.HTTPoisonMock.html","title":"Gitea.HTTPoisonMock","type":"module"},{"doc":"delete/1 mocks the HTTPoison delete function. Feel free refactor this if you can make it pretty.","ref":"Gitea.HTTPoisonMock.html#delete/1","title":"Gitea.HTTPoisonMock.delete/1","type":"function"},{"doc":"get/2 mocks the HTTPoison.get/2 function when parameters match test vars. Feel free refactor this if you can make it pretty.","ref":"Gitea.HTTPoisonMock.html#get/2","title":"Gitea.HTTPoisonMock.get/2","type":"function"},{"doc":"","ref":"Gitea.HTTPoisonMock.html#make_repo_create_post_response_body/1","title":"Gitea.HTTPoisonMock.make_repo_create_post_response_body/1","type":"function"},{"doc":"post/3 mocks the HTTPoison.post/3 function when parameters match test vars. Feel free refactor this if you can make it pretty.","ref":"Gitea.HTTPoisonMock.html#post/3","title":"Gitea.HTTPoisonMock.post/3","type":"function"},{"doc":"post_raw/3 mocks the GiteaHttp.post_raw/3 function. Feel free refactor this if you can make it pretty.","ref":"Gitea.HTTPoisonMock.html#post_raw_html/3","title":"Gitea.HTTPoisonMock.post_raw_html/3","type":"function"},{"doc":"","ref":"Gitea.HTTPoisonMock.html#raw_html/0","title":"Gitea.HTTPoisonMock.raw_html/0","type":"function"},{"doc":"Helper functions that can be unit tested independently of the main functions. If you spot any way to make these better, please share: https://github.com/dwyl/gitea/issues","ref":"Gitea.Helpers.html","title":"Gitea.Helpers","type":"module"},{"doc":"api_base_url/0 returns the Gitea Server REST API url for API requests. Examples iex&gt; Gitea.Helpers.api_base_url() &quot; https://gitea-server.fly.dev/api/v1/&quot;","ref":"Gitea.Helpers.html#api_base_url/0","title":"Gitea.Helpers.api_base_url/0","type":"function"},{"doc":"get_org_name_from_url/1 extracts the organisation name from a .git url. ssh://git@gitea-server.fly.dev:10022/theorg/myrepo.git","ref":"Gitea.Helpers.html#get_org_name_from_url/1","title":"Gitea.Helpers.get_org_name_from_url/1","type":"function"},{"doc":"returns {org, repo} from git url Examples iex&gt; Gitea.Helpers.get_org_repo_names(&quot;git@gitea-server.fly.dev:myorg/myrepo.git&quot;) {&quot;myorg&quot;, &quot;myrepo&quot;} iex&gt; Gitea.Helpers.get_org_repo_names(&quot;ssh://git@gitea-server.fly.dev:10022/theorg/myrepo.git&quot;) {&quot;theorg&quot;, &quot;myrepo&quot;} iex&gt; Gitea.Helpers.get_org_repo_names(&quot; https://gitea-server.fly.dev/myorg/public-repo.git&quot; ) {&quot;myorg&quot;, &quot;public-repo&quot;}","ref":"Gitea.Helpers.html#get_org_repo_names/1","title":"Gitea.Helpers.get_org_repo_names/1","type":"function"},{"doc":"get_repo_name_from_url/1 extracts the repository name from a .git url. Feel free to refactor/simplify this function if you want.","ref":"Gitea.Helpers.html#get_repo_name_from_url/1","title":"Gitea.Helpers.get_repo_name_from_url/1","type":"function"},{"doc":"local_git_repo/2 returns the %Git.Repository{} (struct) for an org and repo on the localhost . This is used by the Git module to perform operations.","ref":"Gitea.Helpers.html#local_git_repo/2","title":"Gitea.Helpers.local_git_repo/2","type":"function"},{"doc":"local_repo_path/2 returns the full system path for the cloned repo on the localhost i.e. the Elixir/Phoenix server that cloned it.","ref":"Gitea.Helpers.html#local_repo_path/2","title":"Gitea.Helpers.local_repo_path/2","type":"function"},{"doc":"make_url/1 constructs the URL based on the supplied git url . Examples iex&gt; Gitea.Helpers.make_url(&quot;gitea-server.fly.dev&quot;) &quot;git@gitea-server.fly.dev:&quot; iex&gt; Gitea.Helpers.make_url(&quot;github.com&quot;) &quot;git@github.com:&quot;","ref":"Gitea.Helpers.html#make_url/1","title":"Gitea.Helpers.make_url/1","type":"function"},{"doc":"remote_url/3 returns the git remote url.","ref":"Gitea.Helpers.html#remote_url/3","title":"Gitea.Helpers.remote_url/3","type":"function"},{"doc":"remote_url_ssh/2 returns the remote ssh url for cloning.","ref":"Gitea.Helpers.html#remote_url_ssh/2","title":"Gitea.Helpers.remote_url_ssh/2","type":"function"},{"doc":"temp_dir/1 returns the Current Working Directory (CWD). Made this a function in case we want to change the location of the directory later e.g. to a temporary directory.","ref":"Gitea.Helpers.html#temp_dir/1","title":"Gitea.Helpers.temp_dir/1","type":"function"},{"doc":"Documentation for the HTTP &quot;verb&quot; functions. Should be self-explanatory. Each function documented &amp; typespecd. If anything is unclear, please open an issue: github.com/dwyl/ gitea/issues","ref":"Gitea.Http.html","title":"Gitea.Http","type":"module"},{"doc":"delete/1 accepts a single argument url ; the url for the repository to be deleted.","ref":"Gitea.Http.html#delete/1","title":"Gitea.Http.delete/1","type":"function"},{"doc":"get/1 accepts one argument: url the REST API endpoint. Makes an HTTP GET request to the specified url . Auth Headers and Content-Type are implicit. returns {:ok, map}","ref":"Gitea.Http.html#get/1","title":"Gitea.Http.get/1","type":"function"},{"doc":"get_raw/1 as it's name suggests gets the raw data (expects the reponse to be plaintext not JSON) accepts one argument: url the REST API endpoint. Makes an HTTP GET request to the specified url . Auth Headers and Content-Type are implicit. returns {:ok, map}","ref":"Gitea.Http.html#get_raw/1","title":"Gitea.Http.get_raw/1","type":"function"},{"doc":"inject_poison/0 injects a TestDouble of HTTPoison in Test. see: https://github.com/dwyl/elixir-auth-google/issues/35","ref":"Gitea.Http.html#inject_poison/0","title":"Gitea.Http.inject_poison/0","type":"function"},{"doc":"parse_body_response/1 parses the response returned by the Gitea Server so your app can use the resulting JSON.","ref":"Gitea.Http.html#parse_body_response/1","title":"Gitea.Http.parse_body_response/1","type":"function"},{"doc":"post/2 accepts two arguments: url and params . Makes an HTTP POST request to the specified url passing in the params as the request body. Auth Headers and Content-Type are implicit.","ref":"Gitea.Http.html#post/2","title":"Gitea.Http.post/2","type":"function"},{"doc":"post_raw_html/2 accepts two arguments: url and raw_markdown . Makes an HTTP POST request to the specified url passing in the params as the request body. Does NOT attempt to parse the response body as JSON. Auth Headers and Content-Type are implicit.","ref":"Gitea.Http.html#post_raw_html/2","title":"Gitea.Http.post_raw_html/2","type":"function"}]